@@ -1,4 +1,4 @@
-# Copyright (c) Acconeer AB, 2022
+# Copyright (c) Acconeer AB, 2022-2023
 # All rights reserved
 
 from __future__ import annotations
@@ -51,6 +51,24 @@ ExtendedProcessorBase = GenericProcessorBase[
 ]
 
 
+class Controller(abc.ABC, Generic[ConfigT, ResultT]):
+    def __init__(self, *, client: a121.ClientBase, config: ConfigT):
+        self.client = client
+        self.config = config
+
+    @abc.abstractmethod
+    def start(self, recorder: Optional[a121.Recorder] = None) -> None:
+        ...
+
+    @abc.abstractmethod
+    def get_next(self) -> ResultT:
+        ...
+
+    @abc.abstractmethod
+    def stop(self) -> Any:
+        ...
+
+
 class AlgoBase:
     def to_dict(self) -> dict[str, Any]:
         return attrs.asdict(self)
