@@ -1,4 +1,4 @@
-# Copyright (c) Acconeer AB, 2022
+# Copyright (c) Acconeer AB, 2022-2023
 # All rights reserved
 
 from __future__ import annotations
@@ -534,22 +534,22 @@ class ViewPlugin(DetectorViewPluginBase):
     @classmethod
     def _get_processor_pidget_mapping(cls) -> PidgetFactoryMapping:
         return {
-            "sensor_spacing_m": pidgets.FloatParameterWidgetFactory(
+            "sensor_spacing_m": pidgets.FloatPidgetFactory(
                 name_label_text="Sensor spacing",
                 suffix=" m",
                 decimals=3,
             ),
-            "max_anticipated_velocity_mps": pidgets.FloatParameterWidgetFactory(
+            "max_anticipated_velocity_mps": pidgets.FloatPidgetFactory(
                 name_label_text="Max anticipated velocity",
                 suffix=" m/s",
                 decimals=1,
             ),
-            "dead_reckoning_duration_s": pidgets.FloatParameterWidgetFactory(
+            "dead_reckoning_duration_s": pidgets.FloatPidgetFactory(
                 name_label_text="Dead reckoning duration",
                 suffix=" s",
                 decimals=1,
             ),
-            "sensitivity": pidgets.FloatSliderParameterWidgetFactory(
+            "sensitivity": pidgets.FloatSliderPidgetFactory(
                 name_label_text="Sensitivity",
                 decimals=2,
                 limits=(0.001, 1),
@@ -563,7 +563,7 @@ class ViewPlugin(DetectorViewPluginBase):
         distance_pidget_mapping = dict(DistanceViewPlugin.get_pidget_mapping())
 
         # Bilateration requires an update rate, so replace the optional float with a mandatory
-        distance_pidget_mapping["update_rate"] = pidgets.FloatParameterWidgetFactory(
+        distance_pidget_mapping["update_rate"] = pidgets.FloatPidgetFactory(
             name_label_text="Update rate",
             decimals=1,
             limits=(1, None),
