@@ -143,7 +143,7 @@ class SingleSensorContext(AlgoBase):
             elif isinstance(v, a121.SensorCalibration):
                 sensor_calibration_group = group.create_group("sensor_calibration")
                 v.to_h5(sensor_calibration_group)
-            elif isinstance(v, np.ndarray) or isinstance(v, float) or isinstance(v, int):
+            elif isinstance(v, (np.ndarray, float, int, np.int64)):
                 group.create_dataset(k, data=v, track_times=False)
             else:
                 raise RuntimeError(
@@ -266,6 +266,8 @@ class SingleSensorContext(AlgoBase):
                     "recorded_threshold_frames"
                 ] = recorded_threshold_frames
 
+        context_dict["extra_context"] = SingleSensorExtraContext(**context_dict["extra_context"])
+
         return SingleSensorContext(**context_dict)
 
 
@@ -339,11 +341,24 @@ class DetectorConfig(AlgoConfigBase):
 
 @attrs.frozen(kw_only=True)
 class DetectorResult:
-    rcs: Optional[npt.NDArray[np.float_]] = attrs.field(default=None)
     distances: Optional[npt.NDArray[np.float_]] = attrs.field(default=None)
+    """Estimated distances (m), sorted according to the selected peak sorting strategy."""
+
+    rcs: Optional[npt.NDArray[np.float_]] = attrs.field(default=None)
+    """Estimated radar cross section (dBsm) corresponding to the peak amplitude of the
+    estimated distances.
+    """
+
     near_edge_status: Optional[bool] = attrs.field(default=None)
+    """Boolean indicating an object close to the start edge, located outside of the
+    measurement range.
+    """
+
     processor_results: list[ProcessorResult] = attrs.field()
+    """Processing result. Used for visualization in Exploration Tool."""
+
     service_extended_result: list[dict[int, a121.Result]] = attrs.field()
+    """Service extended result. Used for visualization in Exploration Tool."""
 
 
 class Detector(Controller[DetectorConfig, Dict[int, DetectorResult]]):
@@ -564,7 +579,7 @@ class Detector(Controller[DetectorConfig, Dict[int, DetectorResult]]):
                     subsweep.start_point = 0
                     # Set num_points to a high number to get sufficient number of data points to
                     # estimate the standard deviation.
-                    subsweep.num_points = 500
+                    subsweep.num_points = 220
 
         extended_metadata = self.client.setup_session(session_config)
         assert isinstance(extended_metadata, list)
@@ -1028,7 +1043,7 @@ class Detector(Controller[DetectorConfig, Dict[int, DetectorResult]]):
         ]
         transition_profiles.append(config.max_profile)
 
-        transition_subgroup_plans: list = []
+        transition_subgroup_plans: list[SubsweepGroupPlan] = []
 
         for i in range(len(transition_profiles) - 1):
             profile = transition_profiles[i]
@@ -1402,7 +1417,7 @@ def _load_algo_data(
     return sensor_id, config, context
 
 
-def _get_group_items(group: h5py.Group) -> list[npt.NDArray]:
+def _get_group_items(group: h5py.Group) -> list[npt.NDArray[Any]]:
     group_items = []
 
     i = 0
