@@ -1,4 +1,4 @@
-# Copyright (c) Acconeer AB, 2022
+# Copyright (c) Acconeer AB, 2022-2023
 # All rights reserved
 
 from __future__ import annotations
@@ -8,9 +8,11 @@ from .app_model import PluginSpec
 
 def load_default_plugins() -> list[PluginSpec]:
     from acconeer.exptool.a121.algo.bilateration._plugin import BILATERATION_PLUGIN
+    from acconeer.exptool.a121.algo.breathing._plugin import BREATHING_PLUGIN
     from acconeer.exptool.a121.algo.distance._detector_plugin import DISTANCE_DETECTOR_PLUGIN
     from acconeer.exptool.a121.algo.phase_tracking._plugin import PHASE_TRACKING_PLUGIN
     from acconeer.exptool.a121.algo.presence._detector_plugin import PRESENCE_DETECTOR_PLUGIN
+    from acconeer.exptool.a121.algo.smart_presence._ref_app_plugin import SMART_PRESENCE_PLUGIN
     from acconeer.exptool.a121.algo.sparse_iq._plugin import SPARSE_IQ_PLUGIN
     from acconeer.exptool.a121.algo.touchless_button._plugin import TOUCHLESS_BUTTON_PLUGIN
     from acconeer.exptool.a121.algo.vibration._plugin import VIBRATION_PLUGIN
@@ -23,4 +25,6 @@ def load_default_plugins() -> list[PluginSpec]:
         TOUCHLESS_BUTTON_PLUGIN,
         VIBRATION_PLUGIN,
         BILATERATION_PLUGIN,
+        BREATHING_PLUGIN,
+        SMART_PRESENCE_PLUGIN,
     ]
