@@ -5,6 +5,8 @@ from __future__ import annotations
 
 import importlib.resources
 import logging
+from enum import Enum
+from functools import partial
 from typing import Any, Optional
 
 import qtawesome as qta
@@ -28,9 +30,12 @@ import pyqtgraph as pg
 
 from acconeer.exptool.app import resources  # type: ignore[attr-defined]
 from acconeer.exptool.app.new._enums import PluginFamily
-from acconeer.exptool.app.new.app_model import AppModel, PluginSpec
+from acconeer.exptool.app.new.app_model import AppModel, PluginPresetSpec, PluginSpec
 from acconeer.exptool.app.new.pluginbase import PlotPluginBase, PluginSpecBase
 
+from .plugin_components.utils import VerticalGroupBox
+from .utils import HorizontalSeparator, ScrollAreaDecorator, TopAlignDecorator
+
 
 log = logging.getLogger(__name__)
 
@@ -69,6 +74,59 @@ class PluginSelectionButtonGroup(QButtonGroup):
         return buttons
 
 
+class PluginPresetButton(QPushButton):
+    def __init__(self, plugin_preset: PluginPresetSpec, default: bool, parent: QWidget) -> None:
+        super().__init__(parent)
+        if default:
+            self.setText(f"{plugin_preset.name} (default)")
+        else:
+            self.setText(plugin_preset.name)
+        if plugin_preset.description is not None:
+            self.setToolTip(plugin_preset.description)
+        self.setStyleSheet("text-align: left; font-weight: bold;")
+
+
+class PluginPresetPlaceholder(QWidget):
+    def __init__(self, app_model: AppModel, parent: Optional[QWidget] = None) -> None:
+        super().__init__(parent)
+
+        app_model.sig_load_plugin.connect(self._on_load_plugin)
+
+        self.app_model = app_model
+        self.setLayout(QVBoxLayout(self))
+        self.layout().setContentsMargins(0, 0, 0, 0)
+        self.layout().setSpacing(11)
+        self.group_box = VerticalGroupBox("Preset Configurations", self)
+        self.layout().addWidget(self.group_box)
+        self.preset_buttons_widget: Optional[QWidget] = None
+
+    def _clear(self) -> None:
+        if self.preset_buttons_widget is not None:
+            self.preset_buttons_widget.deleteLater()
+            self.preset_buttons_widget = None
+
+    def _on_preset_click(self, preset_id: Enum) -> None:
+        self.app_model.set_plugin_preset(preset_id)
+
+    def _on_load_plugin(self, plugin_spec: Optional[PluginSpecBase]) -> None:
+        self._clear()
+        if plugin_spec is not None and plugin_spec.presets is not None:
+            self.preset_buttons_widget = QWidget(self.group_box)
+            self.preset_buttons_widget.setLayout(QVBoxLayout(self.preset_buttons_widget))
+            self.preset_buttons_widget.layout().setContentsMargins(0, 0, 0, 0)
+            self.group_box.layout().addWidget(self.preset_buttons_widget)
+
+            for preset in plugin_spec.presets:
+                default_preset = (
+                    len(plugin_spec.presets) > 1
+                    and preset.preset_id == plugin_spec.default_preset_id
+                    and preset.name.lower() != "default"
+                )
+                button = PluginPresetButton(preset, default_preset, self)
+                self.preset_buttons_widget.layout().addWidget(button)
+                button.clicked.connect(partial(self._on_preset_click, preset.preset_id))
+
+
 class PluginSelection(QWidget):
     def __init__(self, app_model: AppModel, parent: QWidget) -> None:
         super().__init__(parent)
@@ -108,19 +166,12 @@ class PluginSelection(QWidget):
                 label.setWordWrap(True)
                 group_box.layout().addWidget(label)
 
-        self.unload_button = QPushButton("Deselect", self)
-        self.unload_button.setStyleSheet("text-align: left;")
-        self.unload_button.setFlat(True)
-        self.unload_button.clicked.connect(self._on_unload_click)
-        self.layout().addWidget(self.unload_button)
+    def _on_load_click(self) -> None:
+        self.layout().addStretch(1)
 
-    def _on_load_click(self):
         plugin = self.button_group.checkedButton().plugin
         self.app_model.load_plugin(plugin)
 
-    def _on_unload_click(self):
-        self.app_model.load_plugin(None)
-
     def _on_app_model_update(self, app_model: AppModel) -> None:
         plugin: Optional[PluginSpec] = app_model.plugin
 
@@ -136,11 +187,20 @@ class PluginSelection(QWidget):
             button = next(b for b in buttons if b.plugin == plugin)
             button.setChecked(True)
 
-        self.unload_button.setEnabled(plugin is not None)
-
         self.setEnabled(app_model.plugin_state.is_steady)
 
 
+class PluginSelectionArea(QWidget):
+    def __init__(self, app_model: AppModel, parent: Optional[QWidget] = None) -> None:
+        super().__init__(parent)
+        self.setLayout(QVBoxLayout(self))
+        self.layout().addWidget(
+            ScrollAreaDecorator(TopAlignDecorator(PluginSelection(app_model, self)))
+        )
+        self.layout().addWidget(HorizontalSeparator())
+        self.layout().addWidget(PluginPresetPlaceholder(app_model, self))
+
+
 class PlotPlaceholder(QWidget):
     def __init__(self, parent: Optional[QWidget] = None) -> None:
         super().__init__(parent)
@@ -151,7 +211,7 @@ class PlotPlaceholder(QWidget):
         self.layout().addWidget(self._teaser_text())
         self.layout().addStretch(1)
 
-    def _select_module_text(self):
+    def _select_module_text(self) -> QHBoxLayout:
         h_box = QHBoxLayout()
         h_box.addStretch(1)
 
@@ -169,7 +229,7 @@ class PlotPlaceholder(QWidget):
 
         return h_box
 
-    def _teaser_text(self):
+    def _teaser_text(self) -> QLabel:
         teaser_label = QLabel(
             "More detectors and example applications will\nbe released continuously.", self
         )
