@@ -1,7 +1,7 @@
 # Copyright (c) Acconeer AB, 2022
 # All rights reserved
 
-from . import utils
+from . import prompts, utils
 from .platform_install import PlatformInstall
 from .setup_group import SetupGroup
 from .setup_step import RequireFileContentStep, SetupStep, ShellCommandStep
